@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,7 +7,6 @@
 #include "gravatarconfiguresettingsdialogtest.h"
 #include "../src/widgets/gravatarconfiguresettingsdialog.h"
 #include "../src/widgets/gravatarconfiguresettingswidget.h"
-#include <QDialogButtonBox>
 #include <QTest>
 #include <QVBoxLayout>
 
@@ -16,18 +15,18 @@ GravatarConfigureSettingsDialogTest::GravatarConfigureSettingsDialogTest(QObject
 {
 }
 
-GravatarConfigureSettingsDialogTest::~GravatarConfigureSettingsDialogTest()
-{
-}
+GravatarConfigureSettingsDialogTest::~GravatarConfigureSettingsDialogTest() = default;
 
 void GravatarConfigureSettingsDialogTest::shouldHaveDefaultValue()
 {
     Gravatar::GravatarConfigureSettingsDialog dlg;
-    auto *configurewidget = dlg.findChild<Gravatar::GravatarConfigureSettingsWidget *>(QStringLiteral("gravatarconfiguresettings"));
+    auto configurewidget = dlg.findChild<Gravatar::GravatarConfigureSettingsWidget *>(QStringLiteral("gravatarconfiguresettings"));
     QVERIFY(configurewidget);
 
-    auto *topLayout = dlg.findChild<QVBoxLayout *>(QStringLiteral("toplayout"));
+    auto topLayout = dlg.findChild<QVBoxLayout *>(QStringLiteral("toplayout"));
     QVERIFY(topLayout);
 }
 
 QTEST_MAIN(GravatarConfigureSettingsDialogTest)
+
+#include "moc_gravatarconfiguresettingsdialogtest.cpp"
