@@ -23,18 +23,18 @@ GravatarConfigureSettingsWidget::GravatarConfigureSettingsWidget(QWidget *parent
     : QWidget(parent)
 {
     auto topLayout = new QVBoxLayout(this);
-    topLayout->setObjectName(QStringLiteral("mainlayout"));
+    topLayout->setObjectName(QLatin1StringView("mainlayout"));
     topLayout->setContentsMargins(0, 0, 0, 0);
     mUseDefaultPixmap = new QCheckBox(i18n("Use Default Image"), this);
-    mUseDefaultPixmap->setObjectName(QStringLiteral("kcfg_GravatarUseDefaultImage"));
+    mUseDefaultPixmap->setObjectName(QLatin1StringView("kcfg_GravatarUseDefaultImage"));
     topLayout->addWidget(mUseDefaultPixmap);
 
     mUseLibravatar = new QCheckBox(i18n("Use Libravatar"), this);
-    mUseLibravatar->setObjectName(QStringLiteral("kcfg_LibravatarSupportEnabled"));
+    mUseLibravatar->setObjectName(QLatin1StringView("kcfg_LibravatarSupportEnabled"));
     topLayout->addWidget(mUseLibravatar);
 
     mFallbackGravatar = new QCheckBox(i18n("Fallback to Gravatar"), this);
-    mFallbackGravatar->setObjectName(QStringLiteral("kcfg_FallbackToGravatar"));
+    mFallbackGravatar->setObjectName(QLatin1StringView("kcfg_FallbackToGravatar"));
     topLayout->addWidget(mFallbackGravatar);
     connect(mUseLibravatar, &QCheckBox::toggled, mFallbackGravatar, &QCheckBox::setEnabled);
     mFallbackGravatar->setEnabled(false);
@@ -42,30 +42,30 @@ GravatarConfigureSettingsWidget::GravatarConfigureSettingsWidget(QWidget *parent
     auto cacheSizeLayout = new QHBoxLayout;
     topLayout->addLayout(cacheSizeLayout);
     auto lab = new QLabel(i18n("Gravatar Cache Size:"), this);
-    lab->setObjectName(QStringLiteral("gravatarcachesizelabel"));
+    lab->setObjectName(QLatin1StringView("gravatarcachesizelabel"));
     cacheSizeLayout->addWidget(lab);
 
     mGravatarCacheSize = new KPluralHandlingSpinBox(this);
     mGravatarCacheSize->setMinimum(1);
     mGravatarCacheSize->setMaximum(9999);
     mGravatarCacheSize->setSuffix(ki18ncp("add space before image", " image", " images"));
-    mGravatarCacheSize->setObjectName(QStringLiteral("kcfg_GravatarCacheSize"));
+    mGravatarCacheSize->setObjectName(QLatin1StringView("kcfg_GravatarCacheSize"));
     cacheSizeLayout->addWidget(mGravatarCacheSize);
     cacheSizeLayout->addStretch();
 
     auto separator = new KSeparator(this);
-    separator->setObjectName(QStringLiteral("separator"));
+    separator->setObjectName(QLatin1StringView("separator"));
     topLayout->addWidget(separator);
 
     auto buttonLayout = new QHBoxLayout;
     topLayout->addLayout(buttonLayout);
     mClearGravatarCache = new QPushButton(i18n("Clear Gravatar Cache"), this);
-    mClearGravatarCache->setObjectName(QStringLiteral("cleargravatarcachebutton"));
+    mClearGravatarCache->setObjectName(QLatin1StringView("cleargravatarcachebutton"));
     buttonLayout->addWidget(mClearGravatarCache);
     buttonLayout->addStretch();
 
     separator = new KSeparator(this);
-    separator->setObjectName(QStringLiteral("separator2"));
+    separator->setObjectName(QLatin1StringView("separator2"));
     topLayout->addWidget(separator);
 
     connect(mClearGravatarCache, &QAbstractButton::clicked, this, &GravatarConfigureSettingsWidget::slotClearGravatarCache);
